package com.gymtracker.util;

import com.gymtracker.model.Application;
import com.gymtracker.model.Logging;
import io.github.cdimascio.dotenv.Dotenv;
import org.hibernate.SessionFactory;
import org.hibernate.boot.registry.StandardServiceRegistryBuilder;
import org.hibernate.cfg.Configuration;
import org.hibernate.service.ServiceRegistry;

import java.util.Properties;

public class HibernateUtil {
    private static final String name = Dotenv.configure().directory("/").load().get("MYSQL_DATABASE");
    private static final String port = Dotenv.configure().directory("/").load().get("MYSQL_TCP_PORT");
    private static final String username = Dotenv.configure().directory("/").load().get("MYSQL_USER");
    private static final String password = Dotenv.configure().directory("/").load().get("MYSQL_ROOT_PASSWORD");

    private static final String url = String.format("jdbc:mysql://mysql-soap:%s/%s", port, name);

    private static SessionFactory sessionFactory;

    private static SessionFactory buildSessionFactory() {
        System.out.println(url);
        Properties properties = new Properties();
        properties.setProperty("hibernate.dialect", "org.hibernate.dialect.MySQL8Dialect");
        properties.setProperty("hibernate.connection.url", HibernateUtil.url);
        properties.setProperty("hibernate.connection.username", HibernateUtil.username);
        properties.setProperty("hibernate.connection.password", HibernateUtil.password);
        properties.setProperty("hibernate.hbm2ddl.auto", "update");
        properties.put("hibernate.current_session_context_class", "thread");

        Configuration configuration = new Configuration();
        configuration.setProperties(properties);
        configuration.addAnnotatedClass(Logging.class);
        configuration.addAnnotatedClass(Application.class);

        ServiceRegistry serviceRegistry = new StandardServiceRegistryBuilder().applySettings(configuration.getProperties()).build();
        return configuration.buildSessionFactory(serviceRegistry);
    }

    public static SessionFactory getSessionFactory() {
        if (HibernateUtil.sessionFactory == null) {
            HibernateUtil.sessionFactory = HibernateUtil.buildSessionFactory();
        }
        return HibernateUtil.sessionFactory;
    }
}
